@@ -7,31 +7,16 @@ import abc
 import logging
 import pathlib
 
-from ..middleware import FiretailMiddleware
 from ..options import FiretailOptions
 from ..resolver import Resolver
 
-logger = logging.getLogger("firetail.app")
+logger = logging.getLogger('firetail.app')
 
 
 class AbstractApp(metaclass=abc.ABCMeta):
-    def __init__(
-        self,
-        import_name,
-        api_cls,
-        port=None,
-        specification_dir="",
-        host=None,
-        server=None,
-        server_args=None,
-        arguments=None,
-        auth_all_paths=False,
-        debug=None,
-        resolver=None,
-        options=None,
-        skip_error_handlers=False,
-        middlewares=None,
-    ):
+    def __init__(self, import_name, api_cls, port=None, specification_dir='',
+                 host=None, server=None, server_args=None, arguments=None, auth_all_paths=False, debug=None,
+                 resolver=None, options=None, skip_error_handlers=False):
         """
         :param import_name: the name of the application package
         :type import_name: str
@@ -52,8 +37,6 @@ class AbstractApp(metaclass=abc.ABCMeta):
         :param debug: include debugging information
         :type debug: bool
         :param resolver: Callable that maps operationID to a function
-        :param middlewares: Callable that maps operationID to a function
-        :type middlewares: list | None
         """
         self.port = port
         self.host = host
@@ -71,29 +54,22 @@ class AbstractApp(metaclass=abc.ABCMeta):
 
         self.server = server
         self.server_args = dict() if server_args is None else server_args
-
         self.app = self.create_app()
 
-        if middlewares is None:
-            middlewares = FiretailMiddleware.default_middlewares
-        self.middleware = self._apply_middleware(middlewares)
-
         # we get our application root path to avoid duplicating logic
         self.root_path = self.get_root_path()
-        logger.debug("Root Path: %s", self.root_path)
+        logger.debug('Root Path: %s', self.root_path)
 
-        specification_dir = pathlib.Path(
-            specification_dir
-        )  # Ensure specification dir is a Path
+        specification_dir = pathlib.Path(specification_dir)  # Ensure specification dir is a Path
         if specification_dir.is_absolute():
             self.specification_dir = specification_dir
         else:
             self.specification_dir = self.root_path / specification_dir
 
-        logger.debug("Specification directory: %s", self.specification_dir)
+        logger.debug('Specification directory: %s', self.specification_dir)
 
         if not skip_error_handlers:
-            logger.debug("Setting error handlers")
+            logger.debug('Setting error handlers')
             self.set_errors_handlers()
 
     @abc.abstractmethod
@@ -102,12 +78,6 @@ class AbstractApp(metaclass=abc.ABCMeta):
         Creates the user framework application
         """
 
-    @abc.abstractmethod
-    def _apply_middleware(self, middlewares):
-        """
-        Apply middleware to application
-        """
-
     @abc.abstractmethod
     def get_root_path(self):
         """
@@ -120,20 +90,11 @@ class AbstractApp(metaclass=abc.ABCMeta):
         Sets all errors handlers of the user framework application
         """
 
-    def add_api(
-        self,
-        specification,
-        base_path=None,
-        arguments=None,
-        auth_all_paths=None,
-        validate_responses=False,
-        strict_validation=False,
-        resolver=None,
-        resolver_error=None,
-        pythonic_params=False,
-        options=None,
-        validator_map=None,
-    ):
+    def add_api(self, specification, base_path=None, arguments=None,
+                auth_all_paths=None, validate_responses=False,
+                strict_validation=False, resolver=None, resolver_error=None,
+                pythonic_params=False, pass_context_arg_name=None, options=None,
+                validator_map=None):
         """
         Adds an API to the application based on a swagger file or API dict
 
@@ -156,9 +117,10 @@ class AbstractApp(metaclass=abc.ABCMeta):
         :type resolver_error: int | None
         :param pythonic_params: When True CamelCase parameters are converted to snake_case
         :type pythonic_params: bool
-
         :param options: New style options dictionary.
         :type options: dict | None
+        :param pass_context_arg_name: Name of argument in handler functions to pass request context to.
+        :type pass_context_arg_name: str | None
         :param validator_map: map of validators
         :type validator_map: dict
         :rtype: AbstractAPI
@@ -170,16 +132,12 @@ class AbstractApp(metaclass=abc.ABCMeta):
             resolver_error_handler = self._resolver_error_handler
 
         resolver = resolver or self.resolver
-        resolver = Resolver(resolver) if hasattr(resolver, "__call__") else resolver
+        resolver = Resolver(resolver) if hasattr(resolver, '__call__') else resolver
 
-        auth_all_paths = (
-            auth_all_paths if auth_all_paths is not None else self.auth_all_paths
-        )
+        auth_all_paths = auth_all_paths if auth_all_paths is not None else self.auth_all_paths
         # TODO test if base_path starts with an / (if not none)
         arguments = arguments or dict()
-        arguments = dict(
-            self.arguments, **arguments
-        )  # copy global arguments and update with api specific
+        arguments = dict(self.arguments, **arguments)  # copy global arguments and update with api specific
 
         if isinstance(specification, dict):
             specification = specification
@@ -188,41 +146,24 @@ class AbstractApp(metaclass=abc.ABCMeta):
 
         api_options = self.options.extend(options)
 
-        self.middleware.add_api(
-            specification,
-            base_path=base_path,
-            arguments=arguments,
-            resolver=resolver,
-            resolver_error_handler=resolver_error_handler,
-            validate_responses=validate_responses,
-            strict_validation=strict_validation,
-            auth_all_paths=auth_all_paths,
-            debug=self.debug,
-            validator_map=validator_map,
-            pythonic_params=pythonic_params,
-            options=api_options.as_dict(),
-        )
-
-        api = self.api_cls(
-            specification,
-            base_path=base_path,
-            arguments=arguments,
-            resolver=resolver,
-            resolver_error_handler=resolver_error_handler,
-            validate_responses=validate_responses,
-            strict_validation=strict_validation,
-            auth_all_paths=auth_all_paths,
-            debug=self.debug,
-            validator_map=validator_map,
-            pythonic_params=pythonic_params,
-            options=api_options.as_dict(),
-        )
+        api = self.api_cls(specification,
+                           base_path=base_path,
+                           arguments=arguments,
+                           resolver=resolver,
+                           resolver_error_handler=resolver_error_handler,
+                           validate_responses=validate_responses,
+                           strict_validation=strict_validation,
+                           auth_all_paths=auth_all_paths,
+                           debug=self.debug,
+                           validator_map=validator_map,
+                           pythonic_params=pythonic_params,
+                           pass_context_arg_name=pass_context_arg_name,
+                           options=api_options.as_dict())
         return api
 
     def _resolver_error_handler(self, *args, **kwargs):
         from firetail.handlers import ResolverErrorHandler
-
-        return ResolverErrorHandler(self.resolver_error, *args, **kwargs)
+        return ResolverErrorHandler(self.api_cls, self.resolver_error, *args, **kwargs)
 
     def add_url_rule(self, rule, endpoint=None, view_func=None, **options):
         """
@@ -260,9 +201,9 @@ class AbstractApp(metaclass=abc.ABCMeta):
                         limited to (`GET`, `POST` etc.).  By default a rule just listens for `GET` (and implicitly
                         `HEAD`).
         """
-        log_details = {"endpoint": endpoint, "view_func": view_func.__name__}
+        log_details = {'endpoint': endpoint, 'view_func': view_func.__name__}
         log_details.update(options)
-        logger.debug("Adding %s", rule, extra=log_details)
+        logger.debug('Adding %s', rule, extra=log_details)
         self.app.add_url_rule(rule, endpoint, view_func, **options)
 
     def route(self, rule, **options):
@@ -285,13 +226,11 @@ class AbstractApp(metaclass=abc.ABCMeta):
                         limited to (`GET`, `POST` etc.).  By default a rule just listens for `GET` (and implicitly
                         `HEAD`).
         """
-        logger.debug("Adding %s with decorator", rule, extra=options)
+        logger.debug('Adding %s with decorator', rule, extra=options)
         return self.app.route(rule, **options)
 
     @abc.abstractmethod
-    def run(
-        self, port=None, server=None, debug=None, host=None, **options
-    ):  # pragma: no cover
+    def run(self, port=None, server=None, debug=None, host=None, **options):  # pragma: no cover
         """
         Runs the application on a local development server.
         :param host: the host interface to bind on.
@@ -304,3 +243,12 @@ class AbstractApp(metaclass=abc.ABCMeta):
         :type debug: bool
         :param options: options to be forwarded to the underlying server
         """
+
+    def __call__(self, environ, start_response):  # pragma: no cover
+        """
+        Makes the class callable to be WSGI-compliant. As Flask is used to handle requests,
+        this is a passthrough-call to the Flask callable class.
+        This is an abstraction to avoid directly referencing the app attribute from outside the
+        class and protect it from unwanted modification.
+        """
+        return self.app(environ, start_response)
